# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class CassandraAuthTypeEnum(object):

    """Implementation of the 'CassandraAuthType' enum.
    Cassandra Authentication type. Enum: [PASSWORD KERBEROS LDAP] Specifies the
    Cassandra auth type. 'PASSWORD' 'KERBEROS' 'LDAP'


    Attributes:
        PASSWORD: TODO: type description here.
        KERBEROS: TODO: type description here.
        LDAP: TODO: type description here.

    """

    PASSWORD = 'PASSWORD'

    KERBEROS = 'KERBEROS'

    LDAP = 'LDAP'
